==> dl.php?src=linea21_1_1.zip: linea21/publication/sup.php <==
<?
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 


if(isset($_POST['valider'])) {
	$publication_object = new publication;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$publication_object->DeletePublication($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$requete= SQL_getPublicationTitle($id);
$result=$sql_object->DBSelect($requete);
$publi_title=FormatText($result[0]['publi_title']);
$publi_owner=$result[0]['publi_posted_by'];

//////////// Check Droits utilisateur ////////////
if (!HaveRight('publication')) ReloadIndex('admin');
if (GetSessionElement('id')!=$publi_owner && !IsSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['publication']; ?></a>
		</li>
		<li>
			<span><? echo formatnavTitle($GLOBALS['lang']['publication']['sup']." : ". $publi_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<? echo "<h2>".formatTitleh2($publi_title)."</h2>"; ?>
<form id="suppubli" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p class="info"><?php echo $GLOBALS['lang']['divers']['sup_confirm']; ?></p>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_3_1.zip: linea21/publication/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage publication
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 


if(isset($_POST['valider'])) {
	$publication_object = new publication;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$publication_object->DeletePublication($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$requete= SQL_getPublicationTitle($id);
$result=$sql_object->DBSelect($requete);
$publi_title=FormatText($result[0]['publi_title']);
$publi_owner=$result[0]['publi_posted_by'];

//////////// Check Droits utilisateur ////////////
if (!HaveRight('publication')) ReloadIndex('admin');
if (GetSessionElement('id')!=$publi_owner && !IsSuperAdmin()) ReloadIndex('admin');
////////////
?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php" class="chemin_home"><? echo _t('way','home'); ?></a>
		</li>
		<li>
			   <a href="<?php echo $rub_link; ?>" id="chemin_<? echo $rub; ?>" class="chemin_rub"><? echo _t('menu','publication'); ?></a>
		</li>
		<li>
			<span><? echo formatnavTitle(_t('publication','sup')." : ". $publi_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<? echo "<h2>".formatTitleh2($publi_title)."</h2>"; ?>
<form id="suppubli" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p class="info"><?php echo _t('divers','sup_confirm'); ?></p>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo _t('btn','valid') ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
